@@ -13,7 +13,7 @@ our @EXPORT_OK = (
 );
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
-our $VERSION = "v0.21.0";
+our $VERSION = "v0.21.1";
 
 1;
 __END__
@@ -322,6 +322,32 @@ L<https://rxjs.dev/api/operators/distinctUntilChanged>
         op_distinct_until_changed(),
     )->subscribe($observer);
 
+    # {name => 'Peter', grade => 'A'}, {name => 'Mary', grade => 'B'}, complete
+    rx_of(
+        {name => 'Peter', grade => 'A'},
+        {name => 'Peter', grade => 'B'},
+        {name => 'Mary', grade => 'B'},
+        {name => 'Mary', grade => 'A'},
+    )->pipe(
+        op_distinct_until_changed(sub {
+            return $_[0]->{name} eq $_[1]->{name};
+        }),
+    )->subscribe($observer);
+
+=item op_distinct_until_key_changed
+
+L<https://rxjs.dev/api/operators/distinctUntilKeyChanged>
+
+    # {name => 'Peter', grade => 'A'}, {name => 'Mary', grade => 'B'}, complete
+    rx_of(
+        {name => 'Peter', grade => 'A'},
+        {name => 'Peter', grade => 'B'},
+        {name => 'Mary', grade => 'B'},
+        {name => 'Mary', grade => 'A'},
+    )->pipe(
+        op_distinct_until_key_changed('name'),
+    )->subscribe($observer);
+
 =item op_filter
 
 L<https://rxjs.dev/api/operators/filter>
