@@ -12,8 +12,9 @@ use Scalar::Util 'reftype', 'refaddr';
 
 use Exporter 'import';
 our @EXPORT_OK = qw/
-    op_delay op_distinct_until_changed op_filter op_first op_map op_map_to op_merge_map op_multicast
-    op_pairwise op_ref_count op_scan op_share op_start_with op_switch_map op_take op_take_until op_take_while op_tap
+    op_delay op_distinct_until_changed op_distinct_until_key_changed op_filter op_first op_map op_map_to op_merge_map
+    op_multicast op_pairwise op_ref_count op_scan op_share op_start_with op_switch_map op_take op_take_until
+    op_take_while op_tap
 /;
 our %EXPORT_TAGS = (all => \@EXPORT_OK);
 
@@ -82,6 +83,10 @@ sub op_delay {
 }
 
 sub op_distinct_until_changed {
+    my ($comparison_function) = @_;
+
+    $comparison_function //= \&_eqq;
+
     return sub {
         my ($source) = @_;
 
@@ -96,7 +101,7 @@ sub op_distinct_until_changed {
                 next => sub {
                     my @value = @_;
 
-                    if (! $have_prev_value or ! _eqq($prev_value, $value[0])) {
+                    if (! $have_prev_value or ! $comparison_function->($prev_value, $value[0])) {
                         $subscriber->{next}->(@value) if defined $subscriber->{next};
                         $have_prev_value = 1;
                         $prev_value = $value[0];
@@ -111,6 +116,14 @@ sub op_distinct_until_changed {
     };
 }
 
+sub op_distinct_until_key_changed {
+    my ($key) = @_;
+
+    return op_distinct_until_changed(sub {
+        $_[0]->{$key} eq $_[1]->{$key};
+    }),
+}
+
 sub op_filter {
     my ($filtering_sub) = @_;
 
